@@ -186,7 +186,7 @@ class ColumnBase:
             if field_no_path.find('_') > 0:
                 return field_no_path.replace('_', ' ').title()
             else:
-                title = field_no_path[0]
+                title = field_no_path[0].upper()
                 for letter in field_no_path[1:]:
                     if letter.isupper():
                         title += ' '
@@ -225,8 +225,8 @@ class LambdaColumn(ColumnBase):
     def __init__(self, *, lambda_function, **kwargs):
         if not self.initialise(locals()):
             return
+        self.lambda_function = kwargs.pop('lambda_function')
         super().__init__(**kwargs)
-        self.lambda_function = lambda_function
 
     def row_result(self, data_dict, _page_results):
         return self.lambda_function(data_dict.get(self.field))
@@ -389,16 +389,22 @@ class CurrencyColumn(ColumnBase):
         self.column_defs = {'className': 'dt-right'}
 
 
-class BooleanColumn(ColumnBase):
+class BooleanColumn(DatatableColumn):
 
-    choices = ['true', 'false']
+    def __init__(self, *,  choices=None, **kwargs):
+        if not self.initialise(locals()):
+            return
+        super().__init__(**kwargs)
+        if choices:
+            self.choices = choices
+        else:
+            self.choices = ['true', 'false', None]
 
     def row_result(self, data, _page_data):
         try:
-            if data[self.field]:
-                return self.choices[0]
-            else:
-                return self.choices[1]
+            if data[self.field] is None:
+                return self.choices[-1]
+            return self.choices[0] if data[self.field] else self.choices[1]
         except KeyError:
             return
 
